CosServiceApi class
Constructors
CosServiceApi ({BinaryMessenger ? binaryMessenger , String messageChannelSuffix = '' })
Constructor for CosServiceApi . The binaryMessenger named argument is
available for dependency injection. If it is left null, the default
BinaryMessenger will be used which routes to the host platform.
Methods
cancelAll (String serviceKey )
→ Future <void >
deleteBucket (String serviceKey , String bucket , String ? region , SessionQCloudCredentials ? sessionCredentials )
→ Future <void >
deleteObject (String serviceKey , String bucket , String ? region , String cosPath , String ? versionId , SessionQCloudCredentials ? sessionCredentials )
→ Future <void >
doesBucketExist (String serviceKey , String bucket )
→ Future <bool >
doesObjectExist (String serviceKey , String bucket , String cosPath )
→ Future <bool >
getBucket (String serviceKey , String bucket , String ? region , String ? prefix , String ? delimiter , String ? encodingType , String ? marker , int ? maxKeys , SessionQCloudCredentials ? sessionCredentials )
→ Future <BucketContents >
getBucketAccelerate (String serviceKey , String bucket , String ? region , SessionQCloudCredentials ? sessionCredentials )
→ Future <bool >
getBucketLocation (String serviceKey , String bucket , String ? region , SessionQCloudCredentials ? sessionCredentials )
→ Future <String >
getBucketVersioning (String serviceKey , String bucket , String ? region , SessionQCloudCredentials ? sessionCredentials )
→ Future <bool >
getObjectUrl (String bucket , String region , String cosPath , String serviceKey )
→ Future <String >
getPresignedUrl (String serviceKey , String bucket , String cosPath , int ? signValidTime , bool ? signHost , Map <String ? , String ? > ? parameters , String ? region , SessionQCloudCredentials ? sessionCredentials )
→ Future <String >
getService (String serviceKey , SessionQCloudCredentials ? sessionCredentials )
→ Future <ListAllMyBuckets >
headBucket (String serviceKey , String bucket , String ? region , SessionQCloudCredentials ? sessionCredentials )
→ Future <Map <String ? , String ? > >
headObject (String serviceKey , String bucket , String ? region , String cosPath , String ? versionId , SessionQCloudCredentials ? sessionCredentials )
→ Future <Map <String ? , String ? > >
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
preBuildConnection (String bucket , String serviceKey )
→ Future <void >
putBucket (String serviceKey , String bucket , String ? region , bool ? enableMAZ , String ? cosacl , String ? readAccount , String ? writeAccount , String ? readWriteAccount , SessionQCloudCredentials ? sessionCredentials )
→ Future <void >
putBucketAccelerate (String serviceKey , String bucket , String ? region , bool enable , SessionQCloudCredentials ? sessionCredentials )
→ Future <void >
putBucketVersioning (String serviceKey , String bucket , String ? region , bool enable , SessionQCloudCredentials ? sessionCredentials )
→ Future <void >
toString ()
→ String
A string representation of this object.
inherited
tencentcloud_cos_sdk_plugin 1.4.0