CosTransferApi class

Constructors

CosTransferApi({BinaryMessenger? binaryMessenger, String messageChannelSuffix = ''})
Constructor for CosTransferApi. The binaryMessenger named argument is available for dependency injection. If it is left null, the default BinaryMessenger will be used which routes to the host platform.

Properties

hashCode int
The hash code for this object.
no setterinherited
pigeonVar_binaryMessenger BinaryMessenger?
final
pigeonVar_messageChannelSuffix String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel(String taskId, String transferKey) Future<void>
download(String transferKey, String bucket, String cosPath, String? region, String savePath, String? versionId, int? trafficLimit, Map<String, String>? customHeaders, List<String?>? noSignHeaders, int? resultCallbackKey, int? stateCallbackKey, int? progressCallbackKey, SessionQCloudCredentials? sessionCredentials) Future<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause(String taskId, String transferKey) Future<void>
resume(String taskId, String transferKey) Future<void>
toString() String
A string representation of this object.
inherited
upload(String transferKey, String bucket, String cosPath, String? region, String? filePath, Uint8List? byteArr, String? uploadId, String? stroageClass, int? trafficLimit, String? callbackParam, Map<String, String>? customHeaders, List<String?>? noSignHeaders, int? resultCallbackKey, int? stateCallbackKey, int? progressCallbackKey, int? initMultipleUploadCallbackKey, SessionQCloudCredentials? sessionCredentials) Future<String>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

pigeonChannelCodec → const MessageCodec<Object?>