CosTransferApi class
Constructors
CosTransferApi ({BinaryMessenger ? binaryMessenger , String messageChannelSuffix = '' })
Constructor for CosTransferApi . The binaryMessenger named argument is
available for dependency injection. If it is left null, the default
BinaryMessenger will be used which routes to the host platform.
Methods
cancel (String taskId , String transferKey )
→ Future <void >
download (String transferKey , String bucket , String cosPath , String ? region , String savePath , String ? versionId , int ? trafficLimit , int ? resultCallbackKey , int ? stateCallbackKey , int ? progressCallbackKey , SessionQCloudCredentials ? sessionCredentials )
→ Future <String >
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause (String taskId , String transferKey )
→ Future <void >
resume (String taskId , String transferKey )
→ Future <void >
toString ()
→ String
A string representation of this object.
inherited
upload (String transferKey , String bucket , String cosPath , String ? region , String ? filePath , Uint8List ? byteArr , String ? uploadId , String ? stroageClass , int ? trafficLimit , String ? callbackParam , int ? resultCallbackKey , int ? stateCallbackKey , int ? progressCallbackKey , int ? initMultipleUploadCallbackKey , SessionQCloudCredentials ? sessionCredentials )
→ Future <String >
tencentcloud_cos_sdk_plugin 1.4.0